@@ -1,11 +1,13 @@
 package DBIx::Class::DeploymentHandler::HandlesDeploy;
 BEGIN {
-  $DBIx::Class::DeploymentHandler::HandlesDeploy::VERSION = '0.001000_06';
+  $DBIx::Class::DeploymentHandler::HandlesDeploy::VERSION = '0.001000_07';
 }
 use Moose::Role;
 
 # ABSTRACT: Interface for deploy methods
 
+requires 'preinstall';
+
 requires 'prepare_deploy';
 requires 'deploy';
 
@@ -30,12 +32,28 @@ requires 'downgrade_single_step';
 
 DBIx::Class::DeploymentHandler::HandlesDeploy - Interface for deploy methods
 
-=head1 VERSION
+=head1 KNOWN IMPLEMENTATIONS
 
-version 0.001000_06
+=over
+
+=item *
+
+L<DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator>
+
+=item *
+
+L<DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::Deprecated>
+
+=back
 
 =head1 METHODS
 
+=head2 preinstall
+
+ $dh->preinstall
+
+Run scripts before deploying to the database
+
 =head2 prepare_deploy
 
  $dh->prepare_deploy
@@ -97,20 +115,6 @@ Optionally return C<< [ $ddl, $upgrade_sql ] >> where C<$ddl> is the DDL for
 that version of the schema and C<$upgrade_sql> is the SQL that was run to
 upgrade the database.
 
-=head1 KNOWN IMPLEMENTATIONS
-
-=over
-
-=item *
-
-L<DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator>
-
-=item *
-
-L<DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::Deprecated>
-
-=back
-
 =head1 AUTHOR
 
   Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
